# Ansible role for tests using basic scripts

Put this role in your `tests.yml` playbook. The playbook will first install
package dependencies listed on playbook on your localhost, then it will proceed
to run testing.  You can redefine the following variables in
`roles/standard-test-basic/vars/main.yml`:

 * **tests**: A list of test cases
 * **artifacts**: An artifacts directory on localhost to store logs
 * **remote_artifacts**: The directory on the system under test where the logs
   are stored.  Note: if this variable is left undefined, it will default to
   `/tmp/artifacts`
 * **required_packages**: A list of prerequisite packages required by tests.
   Please note that for Atomic Host, additional packages will be installed
   using the `rpm-ostree` command which is affecting the test subject (it's
   similar as rebuilding an rpm package to be tested) so this should be used
   with caution and only when necessary.
 * **required_services**: A list of services to be started before running tests.
   Please use `required_packages` for specifying packages that provide the services.

## Test case parameters

 * **dir**: test directory. default: is the test name
 * **run**: command to run the test. default: ./runtest.sh
 * **timeout**: abort test case after this time. More details on [timeout][1]. default: 0
 * **save_files**: List of extra files to save to artifacts.
   Path to the file is relative to test directory. The files are saved to
   artifacts under test name directory. default: None

Example usage:

    - hosts: localhost
      roles:
      - role: standard-test-basic
        tags:
        - classic
        repositories:
        - repo: "https://src.fedoraproject.org/tests/python.git"
          dest: "python"
        tests:
        - smoke27:
            dir: python/smoke
            run: VERSION=2.7 METHOD=virtualenv ./venv.sh
            save_files:
              - venv.sh
        - smoke37:
            dir: python/smoke
            run: VERSION=3.7 ./venv.sh
            timeout: 1h
        required_packages:
        - python27
        - python37
        - python2-virtualenv
        - python3-virtualenv
        - python2-devel
        - python3-devel

[1]: http://man7.org/linux/man-pages/man1/timeout.1.html
